;/*****************************************************************************
; * @file:    startup_LPC8N04.s
; * @purpose: CMSIS Cortex-M0 Core Device Startup File for the
; *           LPC8N04
; * @version: 1.0
; * @date:    2018-6-21
; *
; * Copyright 1997-2016 Freescale Semiconductor, Inc.
; * Copyright 2016-2018 NXP
; *
; * SPDX-License-Identifier: BSD-3-Clause
; *
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; *
; *****************************************************************************/


                PRESERVE8
                THUMB

; Vector Table Mapped to Address 0 at Reset
                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                IMPORT  |Image$$ARM_LIB_STACK$$ZI$$Limit|

__Vectors       DCD     |Image$$ARM_LIB_STACK$$ZI$$Limit| ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler

                DCD     NMI_Handler
                DCD     HardFault_Handler
                DCD     0
                DCD     0
                DCD     0
__vector_table_0x1c
                DCD     0                         ; Checksum of the first 7 words
                DCD     0
                DCD     0                         ; Enhanced image marker, set to 0x0 for legacy boot
                DCD     0                         ; Pointer to enhanced boot block, set to 0x0 for legacy boot
                DCD     SVC_Handler
                DCD     0
                DCD     0
                DCD     PendSV_Handler
                DCD     SysTick_Handler

                ; External Interrupts
                DCD     PIO0_0_IRQHandler  ; PIO0_0 Start Logic Interrupt
                DCD     PIO0_1_IRQHandler  ; PIO0_1 Start Logic Interrupt
                DCD     PIO0_2_IRQHandler  ; PIO0_2 Start Logic Interrupt
                DCD     PIO0_3_IRQHandler  ; PIO0_3 Start Logic Interrupt
                DCD     PIO0_4_IRQHandler  ; PIO0_4 Start Logic Interrupt
                DCD     PIO0_5_IRQHandler  ; PIO0_5 Start Logic Interrupt
                DCD     PIO0_6_IRQHandler  ; PIO0_6 Start Logic Interrupt
                DCD     PIO0_7_IRQHandler  ; PIO0_7 Start Logic Interrupt
                DCD     PIO0_8_IRQHandler  ; PIO0_8 Start Logic Interrupt
                DCD     PIO0_9_IRQHandler  ; PIO0_9 Start Logic Interrupt
                DCD     PIO0_10_IRQHandler  ; PIO0_10 Start Logic Interrupt
                DCD     RFFIELD_IRQHandler  ; NFC Access Start Logic Interrupt
                DCD     RTCPWREQ_IRQHandler  ; RTC Wakeup Request Start Logic Interrupt
                DCD     NFC_IRQHandler  ; NFC Read/Write Interrupt
                DCD     RTC_IRQHandler  ; RTC Wakeup Interrupt
                DCD     I2C0_IRQHandler  ; I2C0 Interrupt
                DCD     CTIMER0_IRQHandler  ; 16-bit Timer 0 Interrupt
                DCD     PMUFLD_IRQHandler  ; RF Power Detection Interrupt
                DCD     CTIMER1_IRQHandler  ; 32-bit Timer 0 Interrupt
                DCD     PMUBOD_IRQHandler  ; Brown Out Detection Interrupt
                DCD     SSP0_IRQHandler  ; SSP0 Interrupt
                DCD     TSEN_IRQHandler  ; Temperature Sensor Interrupt
                DCD     C2D_IRQHandler  ; Capacitance-to-Digital converter Interrupt
                DCD     Reserved39_IRQHandler  ; Reserved interrupt
                DCD     I2D_IRQHandler  ; Current-to-Digital converter Interrupt
                DCD     ADCDAC_IRQHandler  ; Analog-to-Digital/Digital-to-Analog converter Interrupt
                DCD     WDT_IRQHandler  ; Watchdog Timer Interrupt
                DCD     FLASH_IRQHandler  ; FLASH memory Interrupt
                DCD     EEPROM_IRQHandler  ; EEPROM memory Interrupt
                DCD     Reserved45_IRQHandler  ; Reserved interrupt
                DCD     Reserved46_IRQHandler  ; Reserved interrupt
                DCD     PIO0_IRQHandler  ; GPIO Port 0 Interrupt

                AREA    |.text|, CODE, READONLY

; Reset Handler
Reset_Handler   PROC
                EXPORT  Reset_Handler               [WEAK]
                IMPORT  SystemInit
                IMPORT  __main

                LDR     r0, =SystemInit
                BLX     r0
                LDR     r0, =__main
                BX      r0
                ENDP

; Dummy Exception Handlers (infinite loops which can be modified)
NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP

HardFault_Handler \
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP

SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP

PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP

SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

PIO0_0_IRQHandler\
                PROC
                EXPORT     PIO0_0_IRQHandler        [WEAK]
                LDR        R0, =PIO0_0_DriverIRQHandler
                BX         R0
                ENDP

PIO0_1_IRQHandler\
                PROC
                EXPORT     PIO0_1_IRQHandler        [WEAK]
                LDR        R0, =PIO0_1_DriverIRQHandler
                BX         R0
                ENDP

PIO0_2_IRQHandler\
                PROC
                EXPORT     PIO0_2_IRQHandler        [WEAK]
                LDR        R0, =PIO0_2_DriverIRQHandler
                BX         R0
                ENDP

PIO0_3_IRQHandler\
                PROC
                EXPORT     PIO0_3_IRQHandler        [WEAK]
                LDR        R0, =PIO0_3_DriverIRQHandler
                BX         R0
                ENDP

PIO0_4_IRQHandler\
                PROC
                EXPORT     PIO0_4_IRQHandler        [WEAK]
                LDR        R0, =PIO0_4_DriverIRQHandler
                BX         R0
                ENDP

PIO0_5_IRQHandler\
                PROC
                EXPORT     PIO0_5_IRQHandler        [WEAK]
                LDR        R0, =PIO0_5_DriverIRQHandler
                BX         R0
                ENDP

PIO0_6_IRQHandler\
                PROC
                EXPORT     PIO0_6_IRQHandler        [WEAK]
                LDR        R0, =PIO0_6_DriverIRQHandler
                BX         R0
                ENDP

PIO0_7_IRQHandler\
                PROC
                EXPORT     PIO0_7_IRQHandler        [WEAK]
                LDR        R0, =PIO0_7_DriverIRQHandler
                BX         R0
                ENDP

PIO0_8_IRQHandler\
                PROC
                EXPORT     PIO0_8_IRQHandler        [WEAK]
                LDR        R0, =PIO0_8_DriverIRQHandler
                BX         R0
                ENDP

PIO0_9_IRQHandler\
                PROC
                EXPORT     PIO0_9_IRQHandler        [WEAK]
                LDR        R0, =PIO0_9_DriverIRQHandler
                BX         R0
                ENDP

PIO0_10_IRQHandler\
                PROC
                EXPORT     PIO0_10_IRQHandler        [WEAK]
                LDR        R0, =PIO0_10_DriverIRQHandler
                BX         R0
                ENDP

RFFIELD_IRQHandler\
                PROC
                EXPORT     RFFIELD_IRQHandler        [WEAK]
                LDR        R0, =RFFIELD_DriverIRQHandler
                BX         R0
                ENDP

RTCPWREQ_IRQHandler\
                PROC
                EXPORT     RTCPWREQ_IRQHandler        [WEAK]
                LDR        R0, =RTCPWREQ_DriverIRQHandler
                BX         R0
                ENDP

NFC_IRQHandler\
                PROC
                EXPORT     NFC_IRQHandler        [WEAK]
                LDR        R0, =NFC_DriverIRQHandler
                BX         R0
                ENDP

RTC_IRQHandler\
                PROC
                EXPORT     RTC_IRQHandler        [WEAK]
                LDR        R0, =RTC_DriverIRQHandler
                BX         R0
                ENDP

I2C0_IRQHandler\
                PROC
                EXPORT     I2C0_IRQHandler        [WEAK]
                LDR        R0, =I2C0_DriverIRQHandler
                BX         R0
                ENDP

CTIMER0_IRQHandler\
                PROC
                EXPORT     CTIMER0_IRQHandler        [WEAK]
                LDR        R0, =CTIMER0_DriverIRQHandler
                BX         R0
                ENDP

PMUFLD_IRQHandler\
                PROC
                EXPORT     PMUFLD_IRQHandler        [WEAK]
                LDR        R0, =PMUFLD_DriverIRQHandler
                BX         R0
                ENDP

CTIMER1_IRQHandler\
                PROC
                EXPORT     CTIMER1_IRQHandler        [WEAK]
                LDR        R0, =CTIMER1_DriverIRQHandler
                BX         R0
                ENDP

PMUBOD_IRQHandler\
                PROC
                EXPORT     PMUBOD_IRQHandler        [WEAK]
                LDR        R0, =PMUBOD_DriverIRQHandler
                BX         R0
                ENDP

SSP0_IRQHandler\
                PROC
                EXPORT     SSP0_IRQHandler        [WEAK]
                LDR        R0, =SSP0_DriverIRQHandler
                BX         R0
                ENDP

TSEN_IRQHandler\
                PROC
                EXPORT     TSEN_IRQHandler        [WEAK]
                LDR        R0, =TSEN_DriverIRQHandler
                BX         R0
                ENDP

C2D_IRQHandler\
                PROC
                EXPORT     C2D_IRQHandler        [WEAK]
                LDR        R0, =C2D_DriverIRQHandler
                BX         R0
                ENDP

Reserved39_IRQHandler\
                PROC
                EXPORT     Reserved39_IRQHandler        [WEAK]
                LDR        R0, =Reserved39_DriverIRQHandler
                BX         R0
                ENDP

I2D_IRQHandler\
                PROC
                EXPORT     I2D_IRQHandler        [WEAK]
                LDR        R0, =I2D_DriverIRQHandler
                BX         R0
                ENDP

ADCDAC_IRQHandler\
                PROC
                EXPORT     ADCDAC_IRQHandler        [WEAK]
                LDR        R0, =ADCDAC_DriverIRQHandler
                BX         R0
                ENDP

WDT_IRQHandler\
                PROC
                EXPORT     WDT_IRQHandler        [WEAK]
                LDR        R0, =WDT_DriverIRQHandler
                BX         R0
                ENDP

FLASH_IRQHandler\
                PROC
                EXPORT     FLASH_IRQHandler        [WEAK]
                LDR        R0, =FLASH_DriverIRQHandler
                BX         R0
                ENDP

EEPROM_IRQHandler\
                PROC
                EXPORT     EEPROM_IRQHandler        [WEAK]
                LDR        R0, =EEPROM_DriverIRQHandler
                BX         R0
                ENDP

Reserved45_IRQHandler\
                PROC
                EXPORT     Reserved45_IRQHandler        [WEAK]
                LDR        R0, =Reserved45_DriverIRQHandler
                BX         R0
                ENDP

Reserved46_IRQHandler\
                PROC
                EXPORT     Reserved46_IRQHandler        [WEAK]
                LDR        R0, =Reserved46_DriverIRQHandler
                BX         R0
                ENDP

PIO0_IRQHandler\
                PROC
                EXPORT     PIO0_IRQHandler        [WEAK]
                LDR        R0, =PIO0_DriverIRQHandler
                BX         R0
                ENDP

Default_Handler PROC
                EXPORT     PIO0_0_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_1_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_2_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_3_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_4_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_5_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_6_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_7_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_8_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_9_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_10_DriverIRQHandler        [WEAK]
                EXPORT     RFFIELD_DriverIRQHandler        [WEAK]
                EXPORT     RTCPWREQ_DriverIRQHandler        [WEAK]
                EXPORT     NFC_DriverIRQHandler        [WEAK]
                EXPORT     RTC_DriverIRQHandler        [WEAK]
                EXPORT     I2C0_DriverIRQHandler        [WEAK]
                EXPORT     CTIMER0_DriverIRQHandler        [WEAK]
                EXPORT     PMUFLD_DriverIRQHandler        [WEAK]
                EXPORT     CTIMER1_DriverIRQHandler        [WEAK]
                EXPORT     PMUBOD_DriverIRQHandler        [WEAK]
                EXPORT     SSP0_DriverIRQHandler        [WEAK]
                EXPORT     TSEN_DriverIRQHandler        [WEAK]
                EXPORT     C2D_DriverIRQHandler        [WEAK]
                EXPORT     Reserved39_DriverIRQHandler        [WEAK]
                EXPORT     I2D_DriverIRQHandler        [WEAK]
                EXPORT     ADCDAC_DriverIRQHandler        [WEAK]
                EXPORT     WDT_DriverIRQHandler        [WEAK]
                EXPORT     FLASH_DriverIRQHandler        [WEAK]
                EXPORT     EEPROM_DriverIRQHandler        [WEAK]
                EXPORT     Reserved45_DriverIRQHandler        [WEAK]
                EXPORT     Reserved46_DriverIRQHandler        [WEAK]
                EXPORT     PIO0_DriverIRQHandler        [WEAK]

PIO0_0_DriverIRQHandler
PIO0_1_DriverIRQHandler
PIO0_2_DriverIRQHandler
PIO0_3_DriverIRQHandler
PIO0_4_DriverIRQHandler
PIO0_5_DriverIRQHandler
PIO0_6_DriverIRQHandler
PIO0_7_DriverIRQHandler
PIO0_8_DriverIRQHandler
PIO0_9_DriverIRQHandler
PIO0_10_DriverIRQHandler
RFFIELD_DriverIRQHandler
RTCPWREQ_DriverIRQHandler
NFC_DriverIRQHandler
RTC_DriverIRQHandler
I2C0_DriverIRQHandler
CTIMER0_DriverIRQHandler
PMUFLD_DriverIRQHandler
CTIMER1_DriverIRQHandler
PMUBOD_DriverIRQHandler
SSP0_DriverIRQHandler
TSEN_DriverIRQHandler
C2D_DriverIRQHandler
Reserved39_DriverIRQHandler
I2D_DriverIRQHandler
ADCDAC_DriverIRQHandler
WDT_DriverIRQHandler
FLASH_DriverIRQHandler
EEPROM_DriverIRQHandler
Reserved45_DriverIRQHandler
Reserved46_DriverIRQHandler
PIO0_DriverIRQHandler

                B       .

                ENDP


                ALIGN


                END

